@@ -26,7 +26,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: pgmspace.h,v 1.26.2.2 2006/01/06 21:14:29 joerg_wunsch Exp $ */
+/* $Id: pgmspace.h,v 1.26.2.3 2006/02/28 16:53:57 aesok Exp $ */
 
 /*
    pgmspace.h
@@ -339,7 +339,7 @@ typedef uint64_t  prog_uint64_t PROGMEM;
     __result;                               \
 }))
 
-#if defined (__AVR_ENHANCED__)
+#if defined (__AVR_HAVE_LPMX__)
 #define __LPM(addr)         __LPM_enhanced__(addr)
 #define __LPM_word(addr)    __LPM_word_enhanced__(addr)
 #define __LPM_dword(addr)   __LPM_dword_enhanced__(addr)
@@ -518,7 +518,7 @@ typedef uint64_t  prog_uint64_t PROGMEM;
     __result;                             \
 }))
 
-#if defined (__AVR_ENHANCED__)
+#if defined (__AVR_HAVE_LPMX__)
 #define __ELPM(addr)        __ELPM_enhanced__(addr)
 #define __ELPM_word(addr)   __ELPM_word_enhanced__(addr)
 #define __ELPM_dword(addr)  __ELPM_dword_enhanced__(addr)
